"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.settings = void 0;
const utils_1 = require("./utils");
const Settings = function () {
    let _lang = 'ru';
    let _countDownFrom = 30;
    let _spellCountDownMinutes = false;
    let _spellLastMinuteAsWord = true;
    let _spellLastMinuteAsWordIsWarned = false;
    const res = {};
    Object.defineProperties(res, {
        apply: {
            value: (obj) => {
                utils_1.throwIf.notEnumerableProperty(res, obj);
                for (const key of Object.keys(obj)) {
                    const k = key;
                    const val = obj[k];
                    if (val !== undefined) {
                        // @ts-expect-error
                        res[k] = val;
                    }
                }
            },
        },
        lang: {
            set: lang => {
                utils_1.throwIf.notAllowedLang({ lang });
                _lang = lang;
            },
            get: () => _lang,
            enumerable: true,
        },
        countDownFrom: {
            set: countDownFrom => {
                utils_1.throwIf.notNumberInRange({ countDownFrom }, 0, 60);
                _countDownFrom = Math.round(countDownFrom);
            },
            get: () => _countDownFrom,
            enumerable: true,
        },
        spellCountDownMinutes: {
            set: spellCountDownMinutes => {
                utils_1.throwIf.notBoolean({ spellCountDownMinutes });
                _spellCountDownMinutes = spellCountDownMinutes;
            },
            get: () => _spellCountDownMinutes,
            enumerable: true,
        },
        spellLastMinuteAsWord: {
            set: spellLastMinuteAsWord => {
                utils_1.throwIf.notBoolean({ spellLastMinuteAsWord });
                if (!_spellLastMinuteAsWordIsWarned && res.spellCountDownMinutes) {
                    console.warn('Note: there is no sence to change "spellLastMinuteAsWord" setting value because "spellCountDownMinutes" is true.');
                    _spellLastMinuteAsWordIsWarned = true;
                }
                _spellLastMinuteAsWord = spellLastMinuteAsWord;
            },
            get: () => _spellLastMinuteAsWord,
            enumerable: true,
        },
    });
    return res;
};
exports.settings = new Settings();
if (typeof exports.default === 'function') {
    module.exports = exports.default;
    Object.assign(module.exports, exports);
}
