"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.throwIf = exports.typeOf = void 0;
const typeOf = (v) => ({}).toString.call(v).slice(8, -1);
exports.typeOf = typeOf;
exports.throwIf = {
    notBoolean(obj) {
        for (const key in obj) {
            if (![true, false].includes(obj[key])) {
                throw new Error(`Property "${key}" should be Boolean type.`);
            }
        }
    },
    notAllowedLang(obj) {
        for (const key of Object.keys(obj)) {
            const langs = ['ru', 'ua'];
            if (!langs.includes(obj[key])) {
                throw new Error(`Property "${key}" should be one of provided: ${langs.join(', ')}.`);
            }
        }
    },
    notDate(time) {
        if (!(time instanceof Date)) {
            throw new Error('Sorry. Only Date instances are supported.');
        }
    },
    notNumber(obj) {
        for (const key in obj) {
            if (exports.typeOf(obj[key]) !== 'Number' || Number.isNaN(obj[key])) {
                throw new Error(`Property "${key}" should be a number.`);
            }
        }
    },
    notNumberInRange(obj, from, to) {
        this.notNumber(obj);
        for (const key in obj) {
            if (obj[key] < from || to < obj[key]) {
                throw new Error(`Property "${key}" should be in ${from}..${to} range.`);
            }
        }
    },
    notEnumerableProperty(obj, props) {
        const keys = Object.keys(obj);
        for (const prop in props) {
            if (!keys.includes(prop)) {
                throw new Error(`Unknown setting property as "${prop}".`);
            }
        }
    },
};
if (typeof exports.default === 'function') {
    module.exports = exports.default;
    Object.assign(module.exports, exports);
}
